@@ -113,9 +113,16 @@ void IconNode::render(KTextTemplate::OutputStream *stream, KTextTemplate::Contex
         }
     }
 
+    QString iconPath = KIconLoader::global()->iconPath(iconName, mSizeOrGroup < KIconLoader::LastGroup ? mSizeOrGroup : -mSizeOrGroup);
+    if (iconPath.startsWith(QLatin1String(":/"))) {
+        iconPath = QStringLiteral("qrc") + iconPath;
+    } else {
+        iconPath = QStringLiteral("file://") + iconPath;
+    }
+
     const QString html =
-        QStringLiteral("<img src=\"file://%1\" align=\"top\" height=\"%2\" width=\"%2\" alt=\"%3\" title=\"%4\" />")
-            .arg(KIconLoader::global()->iconPath(iconName, mSizeOrGroup < KIconLoader::LastGroup ? mSizeOrGroup : -mSizeOrGroup))
+        QStringLiteral("<img src=\"%1\" align=\"top\" height=\"%2\" width=\"%2\" alt=\"%3\" title=\"%4\" />")
+            .arg(iconPath)
             .arg(mSizeOrGroup < KIconLoader::LastGroup ? KIconLoader::global()->currentSize(static_cast<KIconLoader::Group>(mSizeOrGroup)) : mSizeOrGroup)
             .arg(altText.isEmpty() ? iconName : altText, altText); // title is intentionally blank if no alt is provided
     (*stream) << KTextTemplate::SafeString(html, KTextTemplate::SafeString::IsSafe);
